package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.projectV2.ZsyzSbbzb;
import com.ruoyi.system.mapper.projectV2.ZsyzSbbzbMapper;
import com.ruoyi.system.service.projectV2.IZsyzSbbzbService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 招商引资_申报_首谈信息_主Service业务层处理
 * 
 * @author boman
 * @date 2023-02-23
 */
@Service
public class ZsyzSbbzbServiceImpl implements IZsyzSbbzbService
{
    @Autowired
    private ZsyzSbbzbMapper zsyzSbbzbMapper;

    /**
     * 查询招商引资_申报_首谈信息_主
     * 
     * @param id 招商引资_申报_首谈信息_主ID
     * @return 招商引资_申报_首谈信息_主
     */
    @Override
    public ZsyzSbbzb selectZsyzSbbzbById(Long id)
    {
        return zsyzSbbzbMapper.selectZsyzSbbzbById(id);
    }

    /**
     * 查询招商引资_申报_首谈信息_主列表
     * 
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 招商引资_申报_首谈信息_主
     */
    @Override
    public List<ZsyzSbbzb> selectZsyzSbbzbList(ZsyzSbbzb zsyzSbbzb)
    {
        return zsyzSbbzbMapper.selectZsyzSbbzbList(zsyzSbbzb);
    }

    /**
     * 新增招商引资_申报_首谈信息_主
     * 
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 结果
     */
    @Override
    public int insertZsyzSbbzb(ZsyzSbbzb zsyzSbbzb)
    {
        zsyzSbbzb.setCreateTime(DateUtils.getNowDate());
        return zsyzSbbzbMapper.insertZsyzSbbzb(zsyzSbbzb);
    }

    /**
     * 修改招商引资_申报_首谈信息_主
     * 
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 结果
     */
    @Override
    public int updateZsyzSbbzb(ZsyzSbbzb zsyzSbbzb)
    {
        zsyzSbbzb.setUpdateTime(DateUtils.getNowDate());
        return zsyzSbbzbMapper.updateZsyzSbbzb(zsyzSbbzb);
    }

    /**
     * 批量删除招商引资_申报_首谈信息_主
     * 
     * @param ids 需要删除的招商引资_申报_首谈信息_主ID
     * @return 结果
     */
    @Override
    public int deleteZsyzSbbzbByIds(Long[] ids)
    {
        return zsyzSbbzbMapper.deleteZsyzSbbzbByIds(ids);
    }

    /**
     * 删除招商引资_申报_首谈信息_主信息
     * 
     * @param id 招商引资_申报_首谈信息_主ID
     * @return 结果
     */
    @Override
    public int deleteZsyzSbbzbById(Long id)
    {
        return zsyzSbbzbMapper.deleteZsyzSbbzbById(id);
    }
}
