package com.ruoyi.web.controller.projectV2;

import java.util.List;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzSbbzb;
import com.ruoyi.system.service.projectV2.IZsyzSbbzbService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_申报_首谈信息_主Controller
 * 
 * @author boman
 * @date 2023-02-23
 */
@RestController
@RequestMapping("/projectV2/sbbzb")
public class ZsyzSbbzbController extends BaseController
{
    @Autowired
    private IZsyzSbbzbService zsyzSbbzbService;

    /**
     * 查询招商引资_申报_首谈信息_主列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzSbbzb zsyzSbbzb)
    {
        startPage();
        List<ZsyzSbbzb> list = zsyzSbbzbService.selectZsyzSbbzbList(zsyzSbbzb);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_申报_首谈信息_主列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:export')")
    @Log(title = "招商引资_申报_首谈信息_主", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ZsyzSbbzb zsyzSbbzb)
    {
        List<ZsyzSbbzb> list = zsyzSbbzbService.selectZsyzSbbzbList(zsyzSbbzb);
        ExcelUtil<ZsyzSbbzb> util = new ExcelUtil<ZsyzSbbzb>(ZsyzSbbzb.class);
        return util.exportExcel(list, "sbbzb");
    }

    /**
     * 获取招商引资_申报_首谈信息_主详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(zsyzSbbzbService.selectZsyzSbbzbById(id));
    }

    /**
     * 新增招商引资_申报_首谈信息_主
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:add')")
    @Log(title = "招商引资_申报_首谈信息_主", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzSbbzb zsyzSbbzb)
    {
        return toAjax(zsyzSbbzbService.insertZsyzSbbzb(zsyzSbbzb));
    }

    /**
     * 修改招商引资_申报_首谈信息_主
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:edit')")
    @Log(title = "招商引资_申报_首谈信息_主", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZsyzSbbzb zsyzSbbzb)
    {
        return toAjax(zsyzSbbzbService.updateZsyzSbbzb(zsyzSbbzb));
    }

    /**
     * 删除招商引资_申报_首谈信息_主
     */
    @PreAuthorize("@ss.hasPermi('projectV2:sbbzb:remove')")
    @Log(title = "招商引资_申报_首谈信息_主", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzSbbzbService.deleteZsyzSbbzbByIds(ids));
    }
}
